@@ -45,18 +45,18 @@ pub fn event(
     })
 }
 
-/// Creates an event that can be subscribed to by clients. Calling this method
-/// will internally borsh serialize the [event](./attr.event.html), base64
-/// encode the bytes, and then add a [msg!](../solana_program/macro.msg.html)
-/// log to the transaction.
+/// Logs an event that can be subscribed to by clients.
+/// Uses the [`sol_log_data`](https://docs.rs/solana-program/latest/solana_program/log/fn.sol_log_data.html)
+/// syscall which results in the following log:
+/// ```ignore
+/// Program data: <Base64EncodedEvent>
+/// ```
 #[proc_macro]
 pub fn emit(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
     let data: proc_macro2::TokenStream = input.into();
     proc_macro::TokenStream::from(quote! {
         {
-            let data = anchor_lang::Event::data(&#data);
-            let msg_str = &anchor_lang::__private::base64::encode(data);
-            anchor_lang::solana_program::msg!(msg_str);
+            anchor_lang::solana_program::log::sol_log_data(&[&anchor_lang::Event::data(&#data)]);
         }
     })
 }
